@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
 # ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
+#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
 # ======================================================================================================================
 """
-This module defines the class |NDPlot| in which generic plot methods for a |NDDataset| are defined.
+This module defines the |NDPlot| class in which generic |NDDataset| plot methods are defined.
 """
 
 __all__ = ["NDPlot", "plot"]
@@ -17,18 +17,19 @@ from cycler import cycler
 import matplotlib as mpl
 from matplotlib.colors import to_rgba
 
-# from mpl_toolkits.mplot3d import Axes3D
 from matplotlib import pyplot as plt
+
 import plotly.graph_objects as go
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 from traitlets import Dict, HasTraits, Instance, Union, default, TraitError
 
-from spectrochempy.utils import get_figure, pathclean
+from spectrochempy.utils.plots import get_figure, _Axes, _Axes3D
+from spectrochempy.utils import pathclean
 from spectrochempy.core.dataset.meta import Meta
 from spectrochempy.core import preferences, plot_preferences, error_
 from spectrochempy.core.plotters.plot1d import plot_1D
-from spectrochempy.core.plotters.plot3d import plot_3D
 from spectrochempy.core.plotters.plot2d import plot_2D
+from spectrochempy.core.plotters.plot3d import plot_3D
 
 
 # from spectrochempy.utils import deprecated
@@ -43,9 +44,6 @@ class PreferencesSet(Meta):
     Preferences setting.
     """
 
-    def __init__(self, **data):
-        super().__init__(**data)
-
     def __getitem__(self, key):
 
         # search on the preferences
@@ -129,7 +127,7 @@ class PreferencesSet(Meta):
                 if alias[0].endswith(key) and (not starts and self.parent is not None):
                     # it is a member of a group but we don't know which one:
                     raise KeyError(
-                        f"Found several keys for {key}: {alias}, so it is ambigous. Please choose on one of them"
+                        f"Found several keys for {key}: {alias}, so it is ambiguous. Please choose on one of them"
                     )
                 else:
                     if any([par.startswith(key) for par in alias]):
@@ -200,7 +198,7 @@ class PreferencesSet(Meta):
 
         Parameters
         ----------
-        key: str
+        key : str
             Name of the parameter for which we want information.
         """
         from spectrochempy.utils import colored, TBold
@@ -225,10 +223,25 @@ class PreferencesSet(Meta):
         print(TBold(f"{key} = {value} \t[default: {default}]"))
         print(f"{help}\n")
 
-    def makestyle(self, filename="mydefault", to_mpl=False):
+    def makestyle(self, stylename="mydefault", to_mpl=False):
+        """
+        Create Matplotlib Style files.
 
-        if filename.startswith("scpy"):
-            error_("`scpy` is READ-ONLY. Please use an another style name.")
+        Parameters
+        ----------
+        stylename :
+        to_mpl :
+
+        Returns
+        --------
+        stylename
+            Name of the style
+
+        """
+        if stylename.startswith("scpy"):
+            error_(
+                "Style name starting with `scpy` are READ-ONLY. Please use an another style name."
+            )
             return
 
         txt = ""
@@ -263,6 +276,9 @@ class PreferencesSet(Meta):
                 continue
 
             val = str(mpl.rcParams[key])
+            if val.startswith("CapStyle") or val.startswith("JoinStyle"):
+                val = val.split(".")[-1]
+
             sav = ""
             while val != sav:
                 sav = val
@@ -309,20 +325,17 @@ class PreferencesSet(Meta):
         for par in nonmplpars:
             txt += f"##@{par:37s} : {getattr(self, par)}\n"
 
-        stylesheet = (pathclean(self.stylesheets) / filename).with_suffix(".mplstyle")
+        stylesheet = (pathclean(self.stylesheets) / stylename).with_suffix(".mplstyle")
         stylesheet.write_text(txt)
 
         if to_mpl:
             # make it also accessible to pyplot
             stylelib = (
-                pathclean(mpl.get_configdir()) / "stylelib" / filename
+                pathclean(mpl.get_configdir()) / "stylelib" / stylename
             ).with_suffix(".mplstyle")
-            stylelib.write_text(txt)
+            stylelib.write_text()
 
-        # plot_preferences.traits()['style'].trait_types = plot_preferences.traits()['style'].trait_types +\
-        #                                                       (Unicode(filename),)
-        self.style = filename
-        return self.style
+        return stylename
 
 
 # ======================================================================================================================
@@ -337,21 +350,23 @@ class NDPlot(HasTraits):
     This class is used as basic plotting interface of the |NDDataset|.
     """
 
-    # variable containing the matplotlib axis defined for a NDArray object.
-    _ax = Instance(plt.Axes, allow_none=True)
+    # Instance of the current matplotlib axis defined for a NDArray object.
+    # The _Axes class subclass matplotlib axes in order to allow methods with
+    # Quantities as arguments
+    _ax = Instance(_Axes, allow_none=True)
 
     # The figure on which this NDArray can be plotted
     _fig = Union((Instance(plt.Figure), Instance(go.Figure)), allow_none=True)
 
-    # The axes on which this dataset and other elements such as projections
+    # A list of axes on which this dataset and other elements such as projections
     # and colorbar can be plotted
-    _ndaxes = Dict(Instance(plt.Axes))
+    _ndaxes = Dict(Instance(_Axes))
 
-    # add metadata to store plot parameters
+    # Metadata to store plot parameters
     _preferences = Instance(PreferencesSet, allow_none=True)
 
     # ------------------------------------------------------------------------
-    # generic plotter and plot related methods or properties
+    # Generic plotter and plot related methods or properties
     # ------------------------------------------------------------------------
     def plot(self, method=None, **kwargs):
         """
@@ -364,17 +379,48 @@ class NDPlot(HasTraits):
         ----------
         method : str, optional, default: "generic"
             Specify with plot method to use.
-        **kwargs : dict, optional
+        **kwargs
             Any optional parameters to pass to the plot method.
+            See plot_1D, plot_2D and plot_3D for a  liste of possible arguments.
+
+        Returns
+        -------
+        axe
+            The axe instance on which the plot has bee performed.
+
+        See Also
+        --------
+        plot_1D
+        plot_pen
+        plot_bar
+        plot_scatter_pen
+        plot_multiple
+        plot_2D
+        plot_stack
+        plot_map
+        plot_image
+        plot_1D
+        plot_surface
+        plot_waterfall
+        multiplot
 
         Examples
         --------
 
+        For 1D data, the default plot is done with method scatter
+
         >>> nd = scp.NDDataset([1, 2, 3])
-        >>> _ = nd.plot()
+        >>> _ = nd.plot()  # default to method="scatter"
 
         or
-        >>> _ = nd.plot(method='scatter')
+        >>> _ = nd.plot(method="scatter")
+
+        Equivalently, one can also specify the method to use as follow:
+        >>> _ = nd.plot_scatter()
+        >>> _ = nd.plot_1D()
+
+        For
+
         """
 
         # --------------------------------------------------------------------
@@ -441,7 +487,7 @@ class NDPlot(HasTraits):
         if not method:
             method = prefs.method_2D if ndim == 2 else prefs.method_1D
 
-        ax3d = "3d" if method in ["surface"] else None
+        ax3d = method in ["surface"]
 
         # Get current figure information
         # ------------------------------
@@ -456,9 +502,11 @@ class NDPlot(HasTraits):
         # they will be ignored
         tax = kwargs.get("twinx", None)
         if tax is not None:
-            if isinstance(tax, plt.Axes):
+            if issubclass(type(tax), mpl.axes.Axes):
                 clear = False
                 ax = tax.twinx()
+                # warning : this currently returns a normal Axes (so units-naive)
+                # TODO: try to solve this
                 ax.name = "main"
                 tax.name = "twin"  # the previous main is renamed!
                 self.ndaxes["main"] = ax
@@ -475,7 +523,7 @@ class NDPlot(HasTraits):
         if ax is not None:
             # ax given in the plot parameters,
             # in this case we will plot on this ax
-            if isinstance(ax, (plt.Axes)):
+            if issubclass(type(ax), mpl.axes.Axes):
                 ax.name = "main"
                 self.ndaxes["main"] = ax
             else:
@@ -489,7 +537,12 @@ class NDPlot(HasTraits):
             # or create a new subplot
             # ax = self._fig.gca(projection=ax3d) :: passing parameters DEPRECATED in matplotlib 3.4
             # ---
-            ax = self._fig.add_subplot(projection=ax3d)
+            if not ax3d:
+                ax = _Axes(self._fig, 1, 1, 1)
+                ax = self._fig.add_subplot(ax)
+            else:
+                ax = _Axes3D(self._fig)
+                ax = self._fig.add_axes(ax, projection="3d")
 
             ax.name = "main"
             self.ndaxes["main"] = ax
@@ -514,15 +567,13 @@ class NDPlot(HasTraits):
 
         linestyles = ["-", "--", ":", "-."]
         markers = ["o", "s", "^"]
-        if ax is not None and (
-            kwargs.pop("scatter", False) or kwargs.pop("scatterpen", False)
-        ):
+        if ax is not None and "scatter" in method:
             ax.set_prop_cycle(
                 cycler("color", colors * len(linestyles) * len(markers))
                 + cycler("linestyle", linestyles * len(colors) * len(markers))
                 + cycler("marker", markers * len(colors) * len(linestyles))
             )
-        elif ax is not None and kwargs.pop("pen", False):
+        elif ax is not None and "scatter" not in method:
             ax.set_prop_cycle(
                 cycler("color", colors * len(linestyles))
                 + cycler("linestyle", linestyles * len(colors))
@@ -597,6 +648,8 @@ class NDPlot(HasTraits):
                 axec.name = "colorbar"
                 self.ndaxes["colorbar"] = axec
 
+        return method
+
     # ------------------------------------------------------------------------
     # resume a figure plot
     # ------------------------------------------------------------------------
@@ -728,7 +781,7 @@ class NDPlot(HasTraits):
                 self._ndaxes[ax.name] = ax
         elif isinstance(axes, dict):
             self._ndaxes.update(axes)
-        elif isinstance(axes, plt.Axes):
+        elif isinstance(axes, _Axes):
             # it's an axe! add it to our list
             self._ndaxes[axes.name] = axes
 
