@@ -6,9 +6,9 @@
 #  =====================================================================================================================
 #
 """
-This module define a generic class to import files and contents.
+This module define a generic class to import directories, files and contents.
 """
-__all__ = ["read"]
+__all__ = ["read", "read_dir"]
 __dataset_methods__ = __all__
 
 from warnings import warn
@@ -16,6 +16,7 @@ from datetime import datetime, timezone
 from traitlets import HasTraits, List, Dict, Type, Unicode
 
 from spectrochempy.utils import pathclean, check_filename_to_open
+from spectrochempy.utils import get_directory_name, get_filenames
 from spectrochempy.utils.exceptions import DimensionsCompatibilityError, ProtocolError
 from spectrochempy.core import warning_
 
@@ -34,12 +35,15 @@ FILETYPES = [
     ("csv", "CSV files (*.csv)"),
     ("excel", "Microsoft Excel files (*.xls)"),
     ("zip", "Compressed folder of data files (*.zip)"),
-    ("quadera", "Quadera ascii files (*.asc)")
+    ("quadera", "Quadera ascii files (*.asc)"),
+    ("carroucell", "Carroucell files (*spa)"),
+    ("galactic", "GRAMS/Thermo Galactic files (*.spc)")
     #  ('all', 'All files (*.*)')
 ]
 ALIAS = [
     ("spg", "omnic"),
     ("spa", "omnic"),
+    ("spc", "galactic"),
     ("srs", "omnic"),
     ("mat", "matlab"),
     ("txt", "labspec"),
@@ -65,10 +69,13 @@ class Importer(HasTraits):
 
     def __init__(self):
 
+        super().__init__()
+
         self.filetypes = dict(FILETYPES)
         temp = list(zip(*FILETYPES))
         temp.reverse()
         self.protocols = dict(zip(*temp))
+
         #  add alias
 
         self.alias = dict(ALIAS)
@@ -82,19 +89,25 @@ class Importer(HasTraits):
         if "merge" not in kwargs.keys():
             # if merge is not specified, but the args are provided as a single list, then will are supposed to merge
             # the datasets. If merge is specified then it has priority.
-            # This is not usefull for the 1D datasets, as if they are compatible they are merged automatically
+            # This is not useful for the 1D datasets, as if they are compatible they are merged automatically
             if args and len(args) == 1 and isinstance(args[0], (list, tuple)):
                 kwargs["merge"] = True
 
         args, kwargs = self._setup_objtype(*args, **kwargs)
         res = check_filename_to_open(*args, **kwargs)
         if res:
+            # Normal return
             self.files = res
         else:
+            # Cancel in dialog!
             return None
 
         for key in self.files.keys():
 
+            if key == "" and kwargs.get("protocol") == ["carroucell"]:
+                key = ".carroucell"
+                self.files = {".carroucell": self.files[""]}
+
             if key == "frombytes":
                 # here we need to read contents
                 for filename, content in self.files[key].items():
@@ -106,16 +119,24 @@ class Importer(HasTraits):
                     self.datasets = self._do_merge(self.datasets, **kwargs)
 
             elif key and key[1:] not in list(zip(*FILETYPES))[0] + list(zip(*ALIAS))[0]:
-                continue
-
+                raise TypeError(f"Filetype `{key}` is unknown in spectrochempy")
             else:
                 # here files are read from the disk using filenames
                 self._switch_protocol(key, self.files, **kwargs)
 
         # now we will reset preference for this newly loaded datasets
         if len(self.datasets) > 0:
+
+            if all(self.datasets) is None:
+                return None
+
             prefs = self.datasets[0].preferences
-            prefs.reset()
+            try:
+                prefs.reset()
+            except (FileNotFoundError, AttributeError):
+                pass
+        else:
+            return None
 
         if len(self.datasets) == 1:
             nd = self.datasets[0]  # a single dataset is returned
@@ -132,7 +153,7 @@ class Importer(HasTraits):
                     nd.name = name
             elif names and len(names) != len(nds):
                 warn(
-                    "length of the `names` list and of the list of datsets mismatch - names not applied"
+                    "length of the `names` list and of the list of datasets mismatch - names not applied"
                 )
             return sorted(
                 nds, key=str
@@ -171,29 +192,36 @@ class Importer(HasTraits):
                 return
         datasets = []
         for filename in files[key]:
-            try:
-                read_ = getattr(self, f"_read_{key[1:]}")
-            except AttributeError:
-                warning_(
-                    f"a file with extension {key} was found in this directory but will be ignored"
-                )
+            filename = pathclean(filename)
+            # try:
+            read_ = getattr(self, f"_read_{key[1:]}")
+            # except AttributeError:
+            #     warning_(
+            #         f"a file with extension {key} was found in this directory but will be ignored"
+            #     )
+            #
             try:
                 res = read_(self.objtype(), filename, **kwargs)
-                if not isinstance(res, list):
-                    datasets.append(res)
-                else:
-                    datasets.extend(res)
+                # sometimes read_ can return None (e.g. non labspec text file)
+                if res is not None:
+                    if not isinstance(res, list):
+                        datasets.append(res)
+                    else:
+                        datasets.extend(res)
 
             except FileNotFoundError:
-                warning_(f"No file with name `{filename}` could be found. Sorry! ")
+                raise
 
             except IOError as e:
                 warning_(str(e))
 
-            except Exception:
-                warning_(
-                    f"The file `{filename}` has a known extension but it could not be read. It is ignored!"
-                )
+            except NotImplementedError as e:
+                warning_(str(e))
+
+            # except Exception as e:
+            #     warning_(
+            #         f"The file `{filename}` has a known extension but it could not be read. It is ignored!"
+            #     )
 
         if len(datasets) > 1:
             datasets = self._do_merge(datasets, **kwargs)
@@ -214,13 +242,14 @@ class Importer(HasTraits):
             if dim0 == 1:
                 merged = kwargs.get("merge", True)  # priority to the keyword setting
         else:
+            # not homogeneous
             merged = kwargs.get("merge", False)
 
         if merged:
             # Try to stack the dataset into a single one
             try:
                 dataset = self.objtype.stack(datasets)
-                if kwargs.pop("sortbydate", True):
+                if dataset.coordset is not None and kwargs.pop("sortbydate", True):
                     dataset.sort(dim="y", inplace=True)
                     dataset.history = (
                         str(datetime.now(timezone.utc)) + ":sorted by date"
@@ -263,8 +292,8 @@ def read(*paths, **kwargs):
         The returned datasets are merged to form a single dataset,
         except if `merge` is set to False. If a source is not provided (i.e. no `filename`, nor `content`),
         a dialog box will be opened to select files.
-    **kwargs : dict
-        See other parameters.
+    **kwargs
+        Optional keyword parameters (see Other Parameters).
 
     Returns
     --------
@@ -275,7 +304,7 @@ def read(*paths, **kwargs):
     ----------------
     protocol : {'scp', 'omnic', 'opus', 'topspin', 'matlab', 'jcamp', 'csv', 'excel'}, optional
         Protocol used for reading. If not provided, the correct protocol
-        is inferred (whnever it is possible) from the file name extension.
+        is inferred (whenever it is possible) from the file name extension.
     directory : str, optional
         From where to read the specified `filename`. If not specified, read in the default ``datadir`` specified in
         SpectroChemPy Preferences.
@@ -297,7 +326,7 @@ def read(*paths, **kwargs):
         Instead of passing a filename for further reading, a bytes content can be directly provided as bytes objects.
         The most convenient way is to use a dictionary. This feature is particularly useful for a GUI Dash application
         to handle drag and drop of files into a Browser.
-        For exemples on how to use this feature, one can look in the ``tests/tests_readers`` directory.
+        For examples on how to use this feature, one can look in the ``tests/tests_readers`` directory.
     listdir : bool, optional
         If True and filename is None, all files present in the provided `directory` are returned (and merged if `merge`
         is True. It is assumed that all the files correspond to current reading protocol (default=True)
@@ -312,6 +341,7 @@ def read(*paths, **kwargs):
     read_labspec : Read Raman LABSPEC spectra.
     read_spg : Read Omnic *.spg grouped spectra.
     read_spa : Read Omnic *.Spa single spectra.
+    read_spc : Read Galactic *.spc files.
     read_srs : Read Omnic series.
     read_csv : Read CSV files.
     read_zip : Read Zip files.
@@ -401,6 +431,81 @@ def read(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
+def read_dir(directory=None, **kwargs):
+    """
+    Read an entire directory.
+
+    Open a list of readable files in a and store data/metadata in a dataset or a list of datasets according to the
+    following rules :
+
+    * 2D spectroscopic data (e.g. valid *.spg files or matlab arrays, etc...) from
+      distinct files are stored in distinct NDdatasets.
+    * 1D spectroscopic data (e.g., *.spa files) in a given directory are grouped
+      into single NDDataset, providing their unique dimension are compatible. If not,
+      an error is generated.
+    * non readable files are ignored
+
+    Parameters
+    ----------
+    directory : str or pathlib
+        Folder where are located the files to read.
+
+    Returns
+    --------
+    read_dir
+        |NDDataset| or list of |NDDataset|.
+
+    Depending on the python version, the order of the datasets in the list may change.
+
+    See Also
+    --------
+    read_topspin : Read TopSpin Bruker NMR spectra.
+    read_omnic : Read Omnic spectra.
+    read_opus : Read OPUS spectra.
+    read_spg : Read Omnic *.spg grouped spectra.
+    read_spa : Read Omnic *.Spa single spectra.
+    read_srs : Read Omnic series.
+    read_csv : Read CSV files.
+    read_zip : Read Zip files.
+    read_matlab : Read Matlab files.
+
+    Examples
+    --------
+
+    >>> scp.preferences.csv_delimiter = ','
+    >>> A = scp.read_dir('irdata')
+    >>> len(A)
+    4
+
+    >>> B = scp.NDDataset.read_dir()
+    """
+    kwargs["listdir"] = True
+    importer = Importer()
+    return importer(directory, **kwargs)
+
+
+# ======================================================================================================================
+# Private functions
+# ======================================================================================================================
+
+
+@importermethod
+def _read_dir(*args, **kwargs):
+    _, directory = args
+    directory = get_directory_name(directory)
+    files = get_filenames(directory, **kwargs)
+    datasets = []
+    valid_extensions = list(zip(*FILETYPES))[0] + list(zip(*ALIAS))[0]
+    for key in [key for key in files.keys() if key[1:] in valid_extensions]:
+        if key:
+            importer = Importer()
+            nd = importer(files[key], **kwargs)
+            if not isinstance(nd, list):
+                nd = [nd]
+            datasets.extend(nd)
+    return datasets
+
+
 # ..............................................................................
 @importermethod
 def _read_scp(*args, **kwargs):
@@ -416,27 +521,27 @@ def _read_(*args, **kwargs):
     if not filename or filename.is_dir():
         return Importer._read_dir(*args, **kwargs)
 
-    protocol = kwargs.get("protocol", None)
-    if protocol and ".scp" in protocol:
-        return dataset.load(filename, **kwargs)
-
-    elif filename and filename.name in ("fid", "ser", "1r", "2rr", "3rrr"):
-        # probably an Topspin NMR file
-        return dataset.read_topspin(filename, **kwargs)
-    elif filename:
-        # try scp format
-        try:
-            return dataset.load(filename, **kwargs)
-        except Exception:
-            # lets try some common format
-            for key in ["omnic", "opus", "topspin", "labspec", "matlab", "jdx"]:
-                try:
-                    _read = getattr(dataset, f"read_{key}")
-                    f = f"{filename}.{key}"
-                    return _read(f, **kwargs)
-                except Exception:
-                    pass
-            raise NotImplementedError
+    # protocol = kwargs.get("protocol", None)
+    # if protocol and ".scp" in protocol:
+    #     return dataset.load(filename, **kwargs)
+    #
+    # elif filename and filename.name in ("fid", "ser", "1r", "2rr", "3rrr"):
+    #     # probably an Topspin NMR file
+    #     return dataset.read_topspin(filename, **kwargs)
+    # elif filename:
+    #     # try scp format
+    #     try:
+    #         return dataset.load(filename, **kwargs)
+    #     except Exception:
+    #         # lets try some common format
+    #         for key in ["omnic", "opus", "topspin", "labspec", "matlab", "jdx"]:
+    #             try:
+    #                 _read = getattr(dataset, f"read_{key}")
+    #                 f = f"{filename}.{key}"
+    #                 return _read(f, **kwargs)
+    #             except Exception:
+    #                 pass
+    #         raise NotImplementedError
 
 
 # ------------------------------------------------------------------
