@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+
 #  =====================================================================================================================
 #  Copyright (©) 2015-$today.year LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
 #  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
@@ -25,6 +26,8 @@ from traitlets import (
 
 from spectrochempy.utils import MetaConfigurable, get_pkg_path, pathclean
 
+# from spectrochempy.core import warning_
+
 
 # ------------------------------------------------------------------
 # available matplotlib styles (equivalent of plt.style.available)
@@ -97,51 +100,45 @@ class PlotPreferences(MetaConfigurable):
     )
     lines_dash_joinstyle = Enum(
         [
-            "JoinStyle.miter",
-            "JoinStyle.round",
-            "JoinStyle.bevel",
+            "miter",
+            "round",
+            "bevel",
             "miter",
             "round",
             "bevel",
         ],
-        default_value="JoinStyle.round",
-        help=r"""JoinStyle.miter|JoinStyle.round|JoinStyle.bevel""",
+        default_value="round",
+        help=r"""miter|round|bevel""",
     ).tag(config=True, kind="")
     lines_dash_capstyle = Enum(
         [
-            "CapStyle.butt",
-            "CapStyle.round",
-            "CapStyle.projecting",
+            "butt",
+            "round",
+            "projecting",
             "butt",
             "round",
             "projecting",
         ],
-        default_value="CapStyle.butt",
-        help=r"""CapStyle.butt|CapStyle.round|CapStyle.projecting""",
+        default_value="butt",
+        help=r"""butt|round|projecting""",
     ).tag(config=True, kind="")
     lines_solid_joinstyle = Enum(
         [
-            "JoinStyle.miter",
-            "JoinStyle.round",
-            "JoinStyle.bevel",
             "miter",
             "round",
             "bevel",
         ],
-        default_value="JoinStyle.round",
-        help=r"""JoinStyle.miter|JoinStyle.round|JoinStyle.bevel""",
+        default_value="round",
+        help=r"""miter|round|bevel""",
     ).tag(config=True, kind="")
     lines_solid_capstyle = Enum(
         [
-            "CapStyle.butt",
-            "CapStyle.round",
-            "CapStyle.projecting",
             "butt",
             "round",
             "projecting",
         ],
-        default_value="CapStyle.round",
-        help=r"""CapStyle.butt|CapStyle.round|CapStyle.projecting""",
+        default_value="round",
+        help=r"""butt|round|projecting""",
     ).tag(config=True, kind="")
     lines_antialiased = Bool(
         True, help=r"""render lines in antialiased (no jaggies)"""
@@ -757,7 +754,7 @@ class PlotPreferences(MetaConfigurable):
         ["tight", "standard"],
         default_value="standard",
         help=r""""tight" or "standard". "tight" is
-    incompatible with pipe-based animation backends but will workd with temporary file based ones:
+    incompatible with pipe-based animation backends but will worked with temporary file based ones:
     e.g. setting animation.writer to ffmpeg will not work, use ffmpeg_file instead""",
     ).tag(config=True, kind="")
     savefig_pad_inches = Float(
@@ -1029,8 +1026,11 @@ class PlotPreferences(MetaConfigurable):
             f = (
                 pathclean(mpl.__file__).parent / "mpl-data" / "stylelib" / _style
             ).with_suffix(".mplstyle")
-            if not f.exists():
-                raise TypeError(f"This style {_style} doesn't exists")
+            # if not f.exists() and _style=='scpy':
+            #     warning_(TypeError(f"The style `{_style}` doesn't exists"))
+            #     f = f.parent / 'classic.mplstyle'
+            #     if not f.exists:
+            #         raise TypeError
         txt = f.read_text()
         pars = txt.split("\n")
         for line in pars:
@@ -1071,6 +1071,7 @@ class PlotPreferences(MetaConfigurable):
                     setattr(self, name_, value)
                 except Exception as e:
                     raise e
+
             if line.strip() and line.strip().startswith("##@"):
                 # SPECTROCHEMPY Parameters
                 name, value = line[3:].split(":", maxsplit=1)
